[nautilus-actions/file-manager-actions] na_factory_object renamed to fma_factory_object



commit 6c8ddaf06a6ca02b1941c9ad09eab6479e32effd
Author: Pierre Wieser <pwieser trychlos org>
Date:   Mon Sep 7 23:31:59 2015 +0200

    na_factory_object renamed to fma_factory_object

 src/api/fma-data-boxed.h                           |    2 +-
 src/core/Makefile.am                               |    4 +-
 .../{na-factory-object.c => fma-factory-object.c}  |  116 ++++++++++----------
 src/core/fma-factory-object.h                      |   77 +++++++++++++
 src/core/fma-ifactory-object.c                     |    6 +-
 src/core/fma-ifactory-provider.c                   |    6 +-
 src/core/fma-object-action.c                       |   14 +-
 src/core/fma-object-menu.c                         |   12 +-
 src/core/fma-object-profile.c                      |   14 +-
 src/core/fma-object.c                              |   14 +-
 src/core/na-factory-object.h                       |   77 -------------
 src/nact/nact-icommand-tab.c                       |    2 +-
 src/nact/nact-tree-ieditable.c                     |    8 +-
 13 files changed, 176 insertions(+), 176 deletions(-)
---
diff --git a/src/api/fma-data-boxed.h b/src/api/fma-data-boxed.h
index 121ea0d..d21d371 100644
--- a/src/api/fma-data-boxed.h
+++ b/src/api/fma-data-boxed.h
@@ -43,7 +43,7 @@
  * types that those defined in fma-data-types.h.
  *
  * Additionally, #FMADataBoxed class holds the #FMADataDef data definition
- * suitable for a NAFactoryObject object. It such provides default value
+ * suitable for a FMAFactoryObject object. It such provides default value
  * and validity status.
  *
  * Since: 2.30
diff --git a/src/core/Makefile.am b/src/core/Makefile.am
index a4f5333..4bd070c 100644
--- a/src/core/Makefile.am
+++ b/src/core/Makefile.am
@@ -64,8 +64,8 @@ libna_core_la_SOURCES = \
        fma-exporter.h                                                                          \
        fma-export-format.c                                                                     \
        fma-export-format.h                                                                     \
-       na-factory-object.c                                                                     \
-       na-factory-object.h                                                                     \
+       fma-factory-object.c                                                                    \
+       fma-factory-object.h                                                                    \
        na-factory-provider.c                                                           \
        na-factory-provider.h                                                           \
        na-gconf-migration.c                                                            \
diff --git a/src/core/na-factory-object.c b/src/core/fma-factory-object.c
similarity index 87%
rename from src/core/na-factory-object.c
rename to src/core/fma-factory-object.c
index 217c910..600d32c 100644
--- a/src/core/na-factory-object.c
+++ b/src/core/fma-factory-object.c
@@ -42,7 +42,7 @@
 #include <api/fma-ifactory-provider.h>
 #include <api/fma-object-api.h>
 
-#include "na-factory-object.h"
+#include "fma-factory-object.h"
 #include "na-factory-provider.h"
 
 typedef gboolean ( *FMADataDefIterFunc )( FMADataDef *def, void *user_data );
@@ -112,16 +112,16 @@ static void         free_data_boxed_list( FMAIFactoryObject *object );
 static void         iter_on_data_defs( const FMADataGroup *idgroups, guint mode, FMADataDefIterFunc pfn, 
void *user_data );
 
 /*
- * na_factory_object_define_properties:
+ * fma_factory_object_define_properties:
  * @class: the #GObjectClass.
  * @groups: the list of #FMADataGroup structure which define the data of the class.
  *
  * Initializes all the properties for the class.
  */
 void
-na_factory_object_define_properties( GObjectClass *class, const FMADataGroup *groups )
+fma_factory_object_define_properties( GObjectClass *class, const FMADataGroup *groups )
 {
-       static const gchar *thisfn = "na_factory_object_define_properties";
+       static const gchar *thisfn = "fma_factory_object_define_properties";
 
        g_return_if_fail( G_IS_OBJECT_CLASS( class ));
 
@@ -136,7 +136,7 @@ na_factory_object_define_properties( GObjectClass *class, const FMADataGroup *gr
 static gboolean
 define_class_properties_iter( const FMADataDef *def, GObjectClass *class )
 {
-       static const gchar *thisfn = "na_factory_object_define_class_properties_iter";
+       static const gchar *thisfn = "fma_factory_object_define_class_properties_iter";
        gboolean stop;
        GParamSpec *spec;
 
@@ -157,14 +157,14 @@ define_class_properties_iter( const FMADataDef *def, GObjectClass *class )
 }
 
 /*
- * na_factory_object_get_data_def:
+ * fma_factory_object_get_data_def:
  * @object: this #FMAIFactoryObject object.
  * @name: the searched name.
  *
  * Returns: the #FMADataDef structure which describes this @name, or %NULL.
  */
 FMADataDef *
-na_factory_object_get_data_def( const FMAIFactoryObject *object, const gchar *name )
+fma_factory_object_get_data_def( const FMAIFactoryObject *object, const gchar *name )
 {
        FMADataDef *def;
 
@@ -192,13 +192,13 @@ na_factory_object_get_data_def( const FMAIFactoryObject *object, const gchar *na
 }
 
 /*
- * na_factory_object_get_data_groups:
+ * fma_factory_object_get_data_groups:
  * @object: the #FMAIFactoryObject instance.
  *
  * Returns: a pointer to the list of #FMADataGroup which define the data.
  */
 FMADataGroup *
-na_factory_object_get_data_groups( const FMAIFactoryObject *object )
+fma_factory_object_get_data_groups( const FMAIFactoryObject *object )
 {
        FMADataGroup *groups;
 
@@ -210,7 +210,7 @@ na_factory_object_get_data_groups( const FMAIFactoryObject *object )
 }
 
 /*
- * na_factory_object_iter_on_boxed:
+ * fma_factory_object_iter_on_boxed:
  * @object: this #FMAIFactoryObject object.
  * @pfn: the function to be called.
  * @user_data: data to be provided to the user function.
@@ -220,7 +220,7 @@ na_factory_object_get_data_groups( const FMAIFactoryObject *object )
  * The @fn called function may return %TRUE to stop the iteration.
  */
 void
-na_factory_object_iter_on_boxed( const FMAIFactoryObject *object, NAFactoryObjectIterBoxedFn pfn, void 
*user_data )
+fma_factory_object_iter_on_boxed( const FMAIFactoryObject *object, FMAFactoryObjectIterBoxedFn pfn, void 
*user_data )
 {
        GList *list, *ibox;
        gboolean stop;
@@ -237,7 +237,7 @@ na_factory_object_iter_on_boxed( const FMAIFactoryObject *object, NAFactoryObjec
 }
 
 /*
- * na_factory_object_get_default:
+ * fma_factory_object_get_default:
  * @object: this #FMAIFactoryObject object.
  * @name: the searched name.
  *
@@ -245,9 +245,9 @@ na_factory_object_iter_on_boxed( const FMAIFactoryObject *object, NAFactoryObjec
  * string which should be g_free() by the caller.
  */
 gchar *
-na_factory_object_get_default( FMAIFactoryObject *object, const gchar *name )
+fma_factory_object_get_default( FMAIFactoryObject *object, const gchar *name )
 {
-       static const gchar *thisfn = "na_factory_object_set_defaults";
+       static const gchar *thisfn = "fma_factory_object_set_defaults";
        gchar *value;
        FMADataDef *def;
 
@@ -257,7 +257,7 @@ na_factory_object_get_default( FMAIFactoryObject *object, const gchar *name )
 
        g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
 
-       def = na_factory_object_get_data_def( object, name );
+       def = fma_factory_object_get_data_def( object, name );
        if( def ){
                value = g_strdup( def->default_value );
        }
@@ -266,15 +266,15 @@ na_factory_object_get_default( FMAIFactoryObject *object, const gchar *name )
 }
 
 /*
- * na_factory_object_set_defaults:
+ * fma_factory_object_set_defaults:
  * @object: this #FMAIFactoryObject object.
  *
  * Implement default values in this new @object.
  */
 void
-na_factory_object_set_defaults( FMAIFactoryObject *object )
+fma_factory_object_set_defaults( FMAIFactoryObject *object )
 {
-       static const gchar *thisfn = "na_factory_object_set_defaults";
+       static const gchar *thisfn = "fma_factory_object_set_defaults";
        FMADataGroup *groups;
        NafoDefaultIter *iter_data;
 
@@ -318,7 +318,7 @@ set_defaults_iter( FMADataDef *def, NafoDefaultIter *data )
 }
 
 /*
- * na_factory_object_move_boxed:
+ * fma_factory_object_move_boxed:
  * @target: the target #FMAIFactoryObject instance.
  * @source: the source #FMAIFactoryObject instance.
  * @boxed: a #FMADataBoxed.
@@ -327,7 +327,7 @@ set_defaults_iter( FMADataDef *def, NafoDefaultIter *data )
  * to be attached to @target one.
  */
 void
-na_factory_object_move_boxed( FMAIFactoryObject *target, const FMAIFactoryObject *source, FMADataBoxed 
*boxed )
+fma_factory_object_move_boxed( FMAIFactoryObject *target, const FMAIFactoryObject *source, FMADataBoxed 
*boxed )
 {
        g_return_if_fail( FMA_IS_IFACTORY_OBJECT( target ));
        g_return_if_fail( FMA_IS_IFACTORY_OBJECT( source ));
@@ -341,13 +341,13 @@ na_factory_object_move_boxed( FMAIFactoryObject *target, const FMAIFactoryObject
                attach_boxed_to_object( target, boxed );
 
                const FMADataDef *src_def = fma_data_boxed_get_data_def( boxed );
-               FMADataDef *tgt_def = na_factory_object_get_data_def( target, src_def->name );
+               FMADataDef *tgt_def = fma_factory_object_get_data_def( target, src_def->name );
                fma_data_boxed_set_data_def( boxed, tgt_def );
        }
 }
 
 /*
- * na_factory_object_copy:
+ * fma_factory_object_copy:
  * @target: the target #FMAIFactoryObject instance.
  * @source: the source #FMAIFactoryObject instance.
  *
@@ -355,9 +355,9 @@ na_factory_object_move_boxed( FMAIFactoryObject *target, const FMAIFactoryObject
  * Takes care of not overriding provider data.
  */
 void
-na_factory_object_copy( FMAIFactoryObject *target, const FMAIFactoryObject *source )
+fma_factory_object_copy( FMAIFactoryObject *target, const FMAIFactoryObject *source )
 {
-       static const gchar *thisfn = "na_factory_object_copy";
+       static const gchar *thisfn = "fma_factory_object_copy";
        GList *dest_list, *idest, *inext;
        GList *src_list, *isrc;
        FMADataBoxed *boxed;
@@ -417,16 +417,16 @@ na_factory_object_copy( FMAIFactoryObject *target, const FMAIFactoryObject *sour
 }
 
 /*
- * na_factory_object_are_equal:
+ * fma_factory_object_are_equal:
  * @a: the first (original) #FMAIFactoryObject instance.
  * @b: the second (current) #FMAIFactoryObject isntance.
  *
  * Returns: %TRUE if @a is equal to @b, %FALSE else.
  */
 gboolean
-na_factory_object_are_equal( const FMAIFactoryObject *a, const FMAIFactoryObject *b )
+fma_factory_object_are_equal( const FMAIFactoryObject *a, const FMAIFactoryObject *b )
 {
-       static const gchar *thisfn = "na_factory_object_are_equal";
+       static const gchar *thisfn = "fma_factory_object_are_equal";
        gboolean are_equal;
        GList *a_list, *b_list, *ia, *ib;
 
@@ -478,15 +478,15 @@ na_factory_object_are_equal( const FMAIFactoryObject *a, const FMAIFactoryObject
 }
 
 /*
- * na_factory_object_is_valid:
+ * fma_factory_object_is_valid:
  * @object: the #FMAIFactoryObject instance whose validity is to be checked.
  *
  * Returns: %TRUE if @object is valid, %FALSE else.
  */
 gboolean
-na_factory_object_is_valid( const FMAIFactoryObject *object )
+fma_factory_object_is_valid( const FMAIFactoryObject *object )
 {
-       static const gchar *thisfn = "na_factory_object_is_valid";
+       static const gchar *thisfn = "fma_factory_object_is_valid";
        gboolean is_valid;
        FMADataGroup *groups;
        GList *list, *iv;
@@ -527,7 +527,7 @@ is_valid_mandatory_iter( const FMADataDef *def, NafoValidIter *data )
        if( def->mandatory ){
                boxed = fma_ifactory_object_get_data_boxed( data->object, def->name );
                if( !boxed ){
-                       g_debug( "na_factory_object_is_valid_mandatory_iter: invalid %s: mandatory but not 
set", def->name );
+                       g_debug( "fma_factory_object_is_valid_mandatory_iter: invalid %s: mandatory but not 
set", def->name );
                        data->is_valid = FALSE;
                }
        }
@@ -537,15 +537,15 @@ is_valid_mandatory_iter( const FMADataDef *def, NafoValidIter *data )
 }
 
 /*
- * na_factory_object_dump:
+ * fma_factory_object_dump:
  * @object: this #FMAIFactoryObject instance.
  *
  * Dumps the content of @object.
  */
 void
-na_factory_object_dump( const FMAIFactoryObject *object )
+fma_factory_object_dump( const FMAIFactoryObject *object )
 {
-       static const gchar *thisfn = "na_factory_object_dump";
+       static const gchar *thisfn = "fma_factory_object_dump";
        static const gchar *prefix = "na-factory-data-";
        GList *list, *it;
        guint length;
@@ -574,19 +574,19 @@ na_factory_object_dump( const FMAIFactoryObject *object )
 }
 
 /*
- * na_factory_object_finalize:
+ * fma_factory_object_finalize:
  * @object: the #FMAIFactoryObject being finalized.
  *
  * Clears all data associated with this @object.
  */
 void
-na_factory_object_finalize( FMAIFactoryObject *object )
+fma_factory_object_finalize( FMAIFactoryObject *object )
 {
        free_data_boxed_list( object );
 }
 
 /*
- * na_factory_object_read_item:
+ * fma_factory_object_read_item:
  * @object: this #FMAIFactoryObject instance.
  * @reader: the #FMAIFactoryProvider which is at the origin of this read.
  * @reader_data: reader data.
@@ -596,9 +596,9 @@ na_factory_object_finalize( FMAIFactoryObject *object )
  * Unserializes the object.
  */
 void
-na_factory_object_read_item( FMAIFactoryObject *object, const FMAIFactoryProvider *reader, void 
*reader_data, GSList **messages )
+fma_factory_object_read_item( FMAIFactoryObject *object, const FMAIFactoryProvider *reader, void 
*reader_data, GSList **messages )
 {
-       static const gchar *thisfn = "na_factory_object_read_item";
+       static const gchar *thisfn = "fma_factory_object_read_item";
 
        g_return_if_fail( FMA_IS_IFACTORY_OBJECT( object ));
        g_return_if_fail( FMA_IS_IFACTORY_PROVIDER( reader ));
@@ -651,7 +651,7 @@ read_data_iter( FMADataDef *def, NafoReadIter *iter )
 }
 
 /*
- * na_factory_object_write_item:
+ * fma_factory_object_write_item:
  * @object: this #FMAIFactoryObject instance.
  * @writer: the #FMAIFactoryProvider which is at the origin of this write.
  * @writer_data: writer data.
@@ -663,9 +663,9 @@ read_data_iter( FMADataDef *def, NafoReadIter *iter )
  * Returns: a FMAIIOProvider operation return code.
  */
 guint
-na_factory_object_write_item( FMAIFactoryObject *object, const FMAIFactoryProvider *writer, void 
*writer_data, GSList **messages )
+fma_factory_object_write_item( FMAIFactoryObject *object, const FMAIFactoryProvider *writer, void 
*writer_data, GSList **messages )
 {
-       static const gchar *thisfn = "na_factory_object_write_item";
+       static const gchar *thisfn = "fma_factory_object_write_item";
        guint code;
        FMADataGroup *groups;
        gchar *msg;
@@ -695,7 +695,7 @@ na_factory_object_write_item( FMAIFactoryObject *object, const FMAIFactoryProvid
                iter->messages = messages;
                iter->code = code;
 
-               na_factory_object_iter_on_boxed( object, ( NAFactoryObjectIterBoxedFn ) write_data_iter, iter 
);
+               fma_factory_object_iter_on_boxed( object, ( FMAFactoryObjectIterBoxedFn ) write_data_iter, 
iter );
 
                code = iter->code;
                g_free( iter );
@@ -722,7 +722,7 @@ write_data_iter( const FMAIFactoryObject *object, FMADataBoxed *boxed, NafoWrite
 }
 
 /*
- * na_factory_object_get_as_value:
+ * fma_factory_object_get_as_value:
  * @object: this #FMAIFactoryObject instance.
  * @name: the elementary data id.
  * @value: the #GValue to be set.
@@ -733,7 +733,7 @@ write_data_iter( const FMAIFactoryObject *object, FMADataBoxed *boxed, NafoWrite
  * This is to be read as "set value from data element".
  */
 void
-na_factory_object_get_as_value( const FMAIFactoryObject *object, const gchar *name, GValue *value )
+fma_factory_object_get_as_value( const FMAIFactoryObject *object, const gchar *name, GValue *value )
 {
        FMADataBoxed *boxed;
 
@@ -748,7 +748,7 @@ na_factory_object_get_as_value( const FMAIFactoryObject *object, const gchar *na
 }
 
 /*
- * na_factory_object_get_as_void:
+ * fma_factory_object_get_as_void:
  * @object: this #FMAIFactoryObject instance.
  * @name: the elementary data whose value is to be got.
  *
@@ -760,7 +760,7 @@ na_factory_object_get_as_value( const FMAIFactoryObject *object, const gchar *na
  * by the caller.
  */
 void *
-na_factory_object_get_as_void( const FMAIFactoryObject *object, const gchar *name )
+fma_factory_object_get_as_void( const FMAIFactoryObject *object, const gchar *name )
 {
        void *value;
        FMADataBoxed *boxed;
@@ -778,14 +778,14 @@ na_factory_object_get_as_void( const FMAIFactoryObject *object, const gchar *nam
 }
 
 /*
- * na_factory_object_is_set:
+ * fma_factory_object_is_set:
  * @object: this #FMAIFactoryObject instance.
  * @name: the elementary data whose value is to be tested.
  *
  * Returns: %TRUE if the value is set (may be %NULL), %FALSE else.
  */
 gboolean
-na_factory_object_is_set( const FMAIFactoryObject *object, const gchar *name )
+fma_factory_object_is_set( const FMAIFactoryObject *object, const gchar *name )
 {
        FMADataBoxed *boxed;
 
@@ -797,7 +797,7 @@ na_factory_object_is_set( const FMAIFactoryObject *object, const gchar *name )
 }
 
 /*
- * na_factory_object_set_from_value:
+ * fma_factory_object_set_from_value:
  * @object: this #FMAIFactoryObject instance.
  * @name: the elementary data id.
  * @value: the #GValue whose content is to be got.
@@ -806,9 +806,9 @@ na_factory_object_is_set( const FMAIFactoryObject *object, const gchar *name )
  * attached to @property_id.
  */
 void
-na_factory_object_set_from_value( FMAIFactoryObject *object, const gchar *name, const GValue *value )
+fma_factory_object_set_from_value( FMAIFactoryObject *object, const gchar *name, const GValue *value )
 {
-       static const gchar *thisfn = "na_factory_object_set_from_value";
+       static const gchar *thisfn = "fma_factory_object_set_from_value";
 
        g_return_if_fail( FMA_IS_IFACTORY_OBJECT( object ));
 
@@ -817,7 +817,7 @@ na_factory_object_set_from_value( FMAIFactoryObject *object, const gchar *name,
                fma_boxed_set_from_value( FMA_BOXED( boxed ), value );
 
        } else {
-               FMADataDef *def = na_factory_object_get_data_def( object, name );
+               FMADataDef *def = fma_factory_object_get_data_def( object, name );
                if( !def ){
                        g_warning( "%s: unknown FMADataDef %s", thisfn, name );
 
@@ -830,7 +830,7 @@ na_factory_object_set_from_value( FMAIFactoryObject *object, const gchar *name,
 }
 
 /*
- * na_factory_object_set_from_void:
+ * fma_factory_object_set_from_void:
  * @object: this #FMAIFactoryObject instance.
  * @name: the elementary data whose value is to be set.
  * @data: the value to set.
@@ -838,9 +838,9 @@ na_factory_object_set_from_value( FMAIFactoryObject *object, const gchar *name,
  * Set the elementary data with the given value.
  */
 void
-na_factory_object_set_from_void( FMAIFactoryObject *object, const gchar *name, const void *data )
+fma_factory_object_set_from_void( FMAIFactoryObject *object, const gchar *name, const void *data )
 {
-       static const gchar *thisfn = "na_factory_object_set_from_void";
+       static const gchar *thisfn = "fma_factory_object_set_from_void";
 
        g_return_if_fail( FMA_IS_IFACTORY_OBJECT( object ));
 
@@ -849,7 +849,7 @@ na_factory_object_set_from_void( FMAIFactoryObject *object, const gchar *name, c
                fma_boxed_set_from_void( FMA_BOXED( boxed ), data );
 
        } else {
-               FMADataDef *def = na_factory_object_get_data_def( object, name );
+               FMADataDef *def = fma_factory_object_get_data_def( object, name );
                if( !def ){
                        g_warning( "%s: unknown FMADataDef %s for %s", thisfn, name, G_OBJECT_TYPE_NAME( 
object ));
 
@@ -966,7 +966,7 @@ free_data_boxed_list( FMAIFactoryObject *object )
 static void
 iter_on_data_defs( const FMADataGroup *groups, guint mode, FMADataDefIterFunc pfn, void *user_data )
 {
-       static const gchar *thisfn = "na_factory_object_iter_on_data_defs";
+       static const gchar *thisfn = "fma_factory_object_iter_on_data_defs";
        FMADataDef *def;
        gboolean stop;
 
diff --git a/src/core/fma-factory-object.h b/src/core/fma-factory-object.h
new file mode 100644
index 0000000..adbca7c
--- /dev/null
+++ b/src/core/fma-factory-object.h
@@ -0,0 +1,77 @@
+/*
+ * FileManager-Actions
+ * A file-manager extension which offers configurable context menu actions.
+ *
+ * Copyright (C) 2005 The GNOME Foundation
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2015 Pierre Wieser and others (see AUTHORS)
+ *
+ * FileManager-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * FileManager-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with FileManager-Actions; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
+ *
+ * Authors:
+ *   Frederic Ruaudel <grumz grumz net>
+ *   Rodrigo Moya <rodrigo gnome-db org>
+ *   Pierre Wieser <pwieser trychlos org>
+ *   ... and many others (see AUTHORS)
+ */
+
+#ifndef __CORE_FMA_FACTORY_OBJECT_H__
+#define __CORE_FMA_FACTORY_OBJECT_H__
+
+/* @title: FMAIFactoryObject
+ * @short_description: The #FMAIFactoryObject Internal Functions
+ * @include: core/fma-factory-object.h
+ *
+ * Declare the function only accessed from core library, i.e. not
+ * published as API.
+ */
+
+#include <api/fma-ifactory-provider.h>
+
+G_BEGIN_DECLS
+
+typedef gboolean ( *FMAFactoryObjectIterBoxedFn )( const FMAIFactoryObject *object, FMADataBoxed *boxed, 
void *data );
+
+#define FMA_IFACTORY_OBJECT_PROP_DATA                  "fma-ifactory-object-prop-data"
+
+void          fma_factory_object_define_properties( GObjectClass *class, const FMADataGroup *groups );
+FMADataDef   *fma_factory_object_get_data_def     ( const FMAIFactoryObject *object, const gchar *name );
+FMADataGroup *fma_factory_object_get_data_groups  ( const FMAIFactoryObject *object );
+void          fma_factory_object_iter_on_boxed    ( const FMAIFactoryObject *object, 
FMAFactoryObjectIterBoxedFn pfn, void *user_data );
+
+gchar        *fma_factory_object_get_default      ( FMAIFactoryObject *object, const gchar *name );
+void          fma_factory_object_set_defaults     ( FMAIFactoryObject *object );
+
+void          fma_factory_object_move_boxed       ( FMAIFactoryObject *target, const FMAIFactoryObject 
*source, FMADataBoxed *boxed );
+
+void          fma_factory_object_copy             ( FMAIFactoryObject *target, const FMAIFactoryObject 
*source );
+gboolean      fma_factory_object_are_equal        ( const FMAIFactoryObject *a, const FMAIFactoryObject *b );
+gboolean      fma_factory_object_is_valid         ( const FMAIFactoryObject *object );
+void          fma_factory_object_dump             ( const FMAIFactoryObject *object );
+void          fma_factory_object_finalize         ( FMAIFactoryObject *object );
+
+void          fma_factory_object_read_item        ( FMAIFactoryObject *object, const FMAIFactoryProvider 
*reader, void *reader_data, GSList **messages );
+guint         fma_factory_object_write_item       ( FMAIFactoryObject *object, const FMAIFactoryProvider 
*writer, void *writer_data, GSList **messages );
+
+void         *fma_factory_object_get_as_void      ( const FMAIFactoryObject *object, const gchar *name );
+void          fma_factory_object_get_as_value     ( const FMAIFactoryObject *object, const gchar *name, 
GValue *value );
+gboolean      fma_factory_object_is_set           ( const FMAIFactoryObject *object, const gchar *name );
+
+void          fma_factory_object_set_from_value   ( FMAIFactoryObject *object, const gchar *name, const 
GValue *value );
+void          fma_factory_object_set_from_void    ( FMAIFactoryObject *object, const gchar *name, const void 
*data );
+
+G_END_DECLS
+
+#endif /* __CORE_FMA_FACTORY_OBJECT_H__ */
diff --git a/src/core/fma-ifactory-object.c b/src/core/fma-ifactory-object.c
index 96ab2ef..a346ad1 100644
--- a/src/core/fma-ifactory-object.c
+++ b/src/core/fma-ifactory-object.c
@@ -35,7 +35,7 @@
 
 #include <api/fma-ifactory-object.h>
 
-#include "na-factory-object.h"
+#include "fma-factory-object.h"
 
 /* private interface data
  */
@@ -220,7 +220,7 @@ fma_ifactory_object_get_as_void( const FMAIFactoryObject *object, const gchar *n
 {
        g_return_val_if_fail( FMA_IS_IFACTORY_OBJECT( object ), NULL );
 
-       return( na_factory_object_get_as_void( object, name ));
+       return( fma_factory_object_get_as_void( object, name ));
 }
 
 /**
@@ -238,5 +238,5 @@ fma_ifactory_object_set_from_void( FMAIFactoryObject *object, const gchar *name,
 {
        g_return_if_fail( FMA_IS_IFACTORY_OBJECT( object ));
 
-       na_factory_object_set_from_void( object, name, data );
+       fma_factory_object_set_from_void( object, name, data );
 }
diff --git a/src/core/fma-ifactory-provider.c b/src/core/fma-ifactory-provider.c
index 7b445ed..2bff157 100644
--- a/src/core/fma-ifactory-provider.c
+++ b/src/core/fma-ifactory-provider.c
@@ -34,7 +34,7 @@
 #include <api/fma-iio-provider.h>
 #include <api/fma-ifactory-provider.h>
 
-#include "na-factory-object.h"
+#include "fma-factory-object.h"
 #include "na-factory-provider.h"
 
 /* private interface data
@@ -191,7 +191,7 @@ fma_ifactory_provider_read_item( const FMAIFactoryProvider *reader, void *reader
        g_return_if_fail( FMA_IS_IFACTORY_OBJECT( object ));
 
        v_factory_provider_read_start( reader, reader_data, object, messages );
-       na_factory_object_read_item( object, reader, reader_data, messages );
+       fma_factory_object_read_item( object, reader, reader_data, messages );
        v_factory_provider_read_done( reader, reader_data, object, messages );
 }
 
@@ -225,7 +225,7 @@ fma_ifactory_provider_write_item( const FMAIFactoryProvider *writer, void *write
        code = v_factory_provider_write_start( writer, writer_data, object, messages );
 
        if( code == FMA_IIO_PROVIDER_CODE_OK ){
-               code = na_factory_object_write_item( object, writer, writer_data, messages );
+               code = fma_factory_object_write_item( object, writer, writer_data, messages );
        }
 
        if( code == FMA_IIO_PROVIDER_CODE_OK ){
diff --git a/src/core/fma-object-action.c b/src/core/fma-object-action.c
index d219297..74c2ad5 100644
--- a/src/core/fma-object-action.c
+++ b/src/core/fma-object-action.c
@@ -41,7 +41,7 @@
 #include <api/fma-object-api.h>
 
 #include "na-factory-provider.h"
-#include "na-factory-object.h"
+#include "fma-factory-object.h"
 
 /* private class data
  */
@@ -171,7 +171,7 @@ class_init( FMAObjectActionClass *klass )
 
        klass->private = g_new0( FMAObjectActionClassPrivate, 1 );
 
-       na_factory_object_define_properties( object_class, action_data_groups );
+       fma_factory_object_define_properties( object_class, action_data_groups );
 }
 
 static void
@@ -198,7 +198,7 @@ instance_get_property( GObject *object, guint property_id, GValue *value, GParam
 
        if( !FMA_OBJECT_ACTION( object )->private->dispose_has_run ){
 
-               na_factory_object_get_as_value( FMA_IFACTORY_OBJECT( object ), g_quark_to_string( property_id 
), value );
+               fma_factory_object_get_as_value( FMA_IFACTORY_OBJECT( object ), g_quark_to_string( 
property_id ), value );
        }
 }
 
@@ -210,7 +210,7 @@ instance_set_property( GObject *object, guint property_id, const GValue *value,
 
        if( !FMA_OBJECT_ACTION( object )->private->dispose_has_run ){
 
-               na_factory_object_set_from_value( FMA_IFACTORY_OBJECT( object ), g_quark_to_string( 
property_id ), value );
+               fma_factory_object_set_from_value( FMA_IFACTORY_OBJECT( object ), g_quark_to_string( 
property_id ), value );
        }
 }
 
@@ -410,7 +410,7 @@ ifactory_object_read_done( FMAIFactoryObject *instance, const FMAIFactoryProvide
 
        /* last, set action defaults
         */
-       na_factory_object_set_defaults( instance );
+       fma_factory_object_set_defaults( instance );
 }
 
 static guint
@@ -493,7 +493,7 @@ read_done_convert_v1_to_v2( FMAIFactoryObject *instance )
        fma_object_attach_profile( instance, profile );
 
        for( ibox = to_move ; ibox ; ibox = ibox->next ){
-               na_factory_object_move_boxed(
+               fma_factory_object_move_boxed(
                                FMA_IFACTORY_OBJECT( profile ), instance, FMA_DATA_BOXED( ibox->data ));
        }
 
@@ -653,7 +653,7 @@ fma_object_action_new_with_defaults( void )
        fma_object_set_new_id( action, NULL );
        fma_object_set_label( action, gettext( NEW_NAUTILUS_ACTION ));
        fma_object_set_toolbar_label( action, gettext( NEW_NAUTILUS_ACTION ));
-       na_factory_object_set_defaults( FMA_IFACTORY_OBJECT( action ));
+       fma_factory_object_set_defaults( FMA_IFACTORY_OBJECT( action ));
 
        profile = fma_object_profile_new_with_defaults();
        fma_object_attach_profile( action, profile );
diff --git a/src/core/fma-object-menu.c b/src/core/fma-object-menu.c
index 0c961cc..2b33e53 100644
--- a/src/core/fma-object-menu.c
+++ b/src/core/fma-object-menu.c
@@ -39,7 +39,7 @@
 #include <api/fma-object-api.h>
 
 #include "na-factory-provider.h"
-#include "na-factory-object.h"
+#include "fma-factory-object.h"
 
 /* private class data
  */
@@ -156,7 +156,7 @@ class_init( FMAObjectMenuClass *klass )
 
        klass->private = g_new0( FMAObjectMenuClassPrivate, 1 );
 
-       na_factory_object_define_properties( object_class, menu_data_groups );
+       fma_factory_object_define_properties( object_class, menu_data_groups );
 }
 
 static void
@@ -183,7 +183,7 @@ instance_get_property( GObject *object, guint property_id, GValue *value, GParam
 
        if( !FMA_OBJECT_MENU( object )->private->dispose_has_run ){
 
-               na_factory_object_get_as_value( FMA_IFACTORY_OBJECT( object ), g_quark_to_string( property_id 
), value );
+               fma_factory_object_get_as_value( FMA_IFACTORY_OBJECT( object ), g_quark_to_string( 
property_id ), value );
        }
 }
 
@@ -195,7 +195,7 @@ instance_set_property( GObject *object, guint property_id, const GValue *value,
 
        if( !FMA_OBJECT_MENU( object )->private->dispose_has_run ){
 
-               na_factory_object_set_from_value( FMA_IFACTORY_OBJECT( object ), g_quark_to_string( 
property_id ), value );
+               fma_factory_object_set_from_value( FMA_IFACTORY_OBJECT( object ), g_quark_to_string( 
property_id ), value );
        }
 }
 
@@ -304,7 +304,7 @@ ifactory_object_read_done( FMAIFactoryObject *instance, const FMAIFactoryProvide
 
        /* last, set menu defaults
         */
-       na_factory_object_set_defaults( instance );
+       fma_factory_object_set_defaults( instance );
 }
 
 static guint
@@ -371,7 +371,7 @@ fma_object_menu_new_with_defaults( void )
        FMAObjectMenu *menu = fma_object_menu_new();
        fma_object_set_new_id( menu, NULL );
        fma_object_set_label( menu, gettext( NEW_NAUTILUS_MENU ));
-       na_factory_object_set_defaults( FMA_IFACTORY_OBJECT( menu ));
+       fma_factory_object_set_defaults( FMA_IFACTORY_OBJECT( menu ));
 
        return( menu );
 }
diff --git a/src/core/fma-object-profile.c b/src/core/fma-object-profile.c
index 6e690ef..48b8f0b 100644
--- a/src/core/fma-object-profile.c
+++ b/src/core/fma-object-profile.c
@@ -42,7 +42,7 @@
 #include <api/fma-object-api.h>
 
 #include "na-factory-provider.h"
-#include "na-factory-object.h"
+#include "fma-factory-object.h"
 #include "na-selected-info.h"
 #include "na-gnome-vfs-uri.h"
 
@@ -178,7 +178,7 @@ class_init( FMAObjectProfileClass *klass )
 
        klass->private = g_new0( FMAObjectProfileClassPrivate, 1 );
 
-       na_factory_object_define_properties( object_class, profile_data_groups );
+       fma_factory_object_define_properties( object_class, profile_data_groups );
 }
 
 static void
@@ -207,7 +207,7 @@ instance_get_property( GObject *object, guint property_id, GValue *value, GParam
 
        if( !FMA_OBJECT_PROFILE( object )->private->dispose_has_run ){
 
-               na_factory_object_get_as_value( FMA_IFACTORY_OBJECT( object ), g_quark_to_string( property_id 
), value );
+               fma_factory_object_get_as_value( FMA_IFACTORY_OBJECT( object ), g_quark_to_string( 
property_id ), value );
        }
 }
 
@@ -219,7 +219,7 @@ instance_set_property( GObject *object, guint property_id, const GValue *value,
 
        if( !FMA_OBJECT_PROFILE( object )->private->dispose_has_run ){
 
-               na_factory_object_set_from_value( FMA_IFACTORY_OBJECT( object ), g_quark_to_string( 
property_id ), value );
+               fma_factory_object_set_from_value( FMA_IFACTORY_OBJECT( object ), g_quark_to_string( 
property_id ), value );
        }
 }
 
@@ -587,7 +587,7 @@ convert_pre_v3_isfiledir( FMAObjectProfile *profile )
                 * value when the data is not set (see #651911)
                 */
                isfile = TRUE;
-               if( na_factory_object_is_set( FMA_IFACTORY_OBJECT( profile ), FMAFO_DATA_ISFILE )){
+               if( fma_factory_object_is_set( FMA_IFACTORY_OBJECT( profile ), FMAFO_DATA_ISFILE )){
                        isfile = fma_object_is_file( profile );
                }
                isdir = fma_object_is_dir( profile );
@@ -647,7 +647,7 @@ read_done_ending( FMAObjectProfile *profile )
 
        /* last, set profile defaults
         */
-       na_factory_object_set_defaults( FMA_IFACTORY_OBJECT( profile ));
+       fma_factory_object_set_defaults( FMA_IFACTORY_OBJECT( profile ));
 }
 
 /*
@@ -766,7 +766,7 @@ fma_object_profile_new_with_defaults( void )
        fma_object_set_id( profile, "profile-zero" );
        /* i18n: label for the default profile */
        fma_object_set_label( profile, _( "Default profile" ));
-       na_factory_object_set_defaults( FMA_IFACTORY_OBJECT( profile ));
+       fma_factory_object_set_defaults( FMA_IFACTORY_OBJECT( profile ));
 
        return( profile );
 }
diff --git a/src/core/fma-object.c b/src/core/fma-object.c
index 4423a67..4d9fe26 100644
--- a/src/core/fma-object.c
+++ b/src/core/fma-object.c
@@ -33,7 +33,7 @@
 
 #include <api/fma-object-api.h>
 
-#include "na-factory-object.h"
+#include "fma-factory-object.h"
 
 /* private class data
  */
@@ -184,7 +184,7 @@ instance_finalize( GObject *object )
        g_free( self->private );
 
        if( FMA_IS_IFACTORY_OBJECT( object )){
-               na_factory_object_finalize( FMA_IFACTORY_OBJECT( object ));
+               fma_factory_object_finalize( FMA_IFACTORY_OBJECT( object ));
        }
 
        /* chain call to parent class */
@@ -201,7 +201,7 @@ object_dump( const FMAObject *object )
                fma_iduplicable_dump( FMA_IDUPLICABLE( object ));
 
                if( FMA_IS_IFACTORY_OBJECT( object )){
-                       na_factory_object_dump( FMA_IFACTORY_OBJECT( object ));
+                       fma_factory_object_dump( FMA_IFACTORY_OBJECT( object ));
                }
        }
 }
@@ -244,7 +244,7 @@ iduplicable_copy( FMAIDuplicable *target, const FMAIDuplicable *source, guint mo
                                mode );
 
                if( FMA_IS_IFACTORY_OBJECT( target )){
-                       na_factory_object_copy( FMA_IFACTORY_OBJECT( target ), FMA_IFACTORY_OBJECT( source ));
+                       fma_factory_object_copy( FMA_IFACTORY_OBJECT( target ), FMA_IFACTORY_OBJECT( source 
));
                }
 
                if( FMA_IS_ICONTEXT( target )){
@@ -274,7 +274,7 @@ iduplicable_are_equal( const FMAIDuplicable *a, const FMAIDuplicable *b )
                are_equal = TRUE;
 
                if( FMA_IS_IFACTORY_OBJECT( a )){
-                       are_equal &= na_factory_object_are_equal( FMA_IFACTORY_OBJECT( a ), 
FMA_IFACTORY_OBJECT( b ));
+                       are_equal &= fma_factory_object_are_equal( FMA_IFACTORY_OBJECT( a ), 
FMA_IFACTORY_OBJECT( b ));
                }
 
                if( FMA_IS_ICONTEXT( a )){
@@ -303,7 +303,7 @@ iduplicable_is_valid( const FMAIDuplicable *object )
                is_valid = TRUE;
 
                if( FMA_IS_IFACTORY_OBJECT( object )){
-                       is_valid &= na_factory_object_is_valid( FMA_IFACTORY_OBJECT( object ));
+                       is_valid &= fma_factory_object_is_valid( FMA_IFACTORY_OBJECT( object ));
                }
 
                if( FMA_IS_ICONTEXT( object )){
@@ -335,7 +335,7 @@ iduplicable_is_valid( const FMAIDuplicable *object )
  *      |      which happens to be iduplicable_are_equal( a, b )
  *      |       +- v_are_equal( a, b )
  *      |           +- FMAObjectAction::are_equal()
- *      |               +- na_factory_object_are_equal()
+ *      |               +- fma_factory_object_are_equal()
  *      |               +- check FMAObjectActionPrivate data
  *      |               +- call parent class
  *      |                  +- FMAObjectItem::are_equal()
diff --git a/src/nact/nact-icommand-tab.c b/src/nact/nact-icommand-tab.c
index aa78cd0..069d22f 100644
--- a/src/nact/nact-icommand-tab.c
+++ b/src/nact/nact-icommand-tab.c
@@ -37,7 +37,7 @@
 #include "api/fma-core-utils.h"
 #include "api/fma-object-api.h"
 
-#include "core/na-factory-object.h"
+#include "core/fma-factory-object.h"
 #include "core/na-gtk-utils.h"
 #include "core/na-tokens.h"
 
diff --git a/src/nact/nact-tree-ieditable.c b/src/nact/nact-tree-ieditable.c
index 3c723d0..10c042f 100644
--- a/src/nact/nact-tree-ieditable.c
+++ b/src/nact/nact-tree-ieditable.c
@@ -34,7 +34,7 @@
 #include <api/fma-core-utils.h>
 #include <api/fma-object-api.h>
 
-#include <core/na-factory-object.h>
+#include <core/fma-factory-object.h>
 #include <core/na-updater.h>
 
 #include "base-keysyms.h"
@@ -958,15 +958,15 @@ nact_tree_ieditable_set_items( NactTreeIEditable *instance, GList *items )
                                        G_OBJECT_TYPE_NAME( old_item ), G_OBJECT_TYPE_NAME( new_item ));
 
                } else if( FMA_IS_OBJECT_MENU( old_item )){
                        /* hopefully, na_factory_object_copy only copy valuable properties
                         * keeping dynamic variables as parent pointer, provider and provider
                         * data, read-only status - notably children are not impacted by this
                         * copy
                         */
-                       na_factory_object_copy( FMA_IFACTORY_OBJECT( old_item ), FMA_IFACTORY_OBJECT( 
new_item ));
+                       fma_factory_object_copy( FMA_IFACTORY_OBJECT( old_item ), FMA_IFACTORY_OBJECT( 
new_item ));
 
                } else if( FMA_IS_OBJECT_ACTION( old_item )){
-                       /* na_factory_object is not a deep copy, which is fine for the menu
+                       /* fma_factory_object is not a deep copy, which is fine for the menu
                         * but not for the action - it appears more easier to just substitute
                         * the old item with the new one
                         *
@@ -958,15 +958,15 @@ nact_tree_ieditable_set_items( NactTreeIEditable *instance, GList *items )
 
                } else if( FMA_IS_OBJECT_MENU( old_item )){
-                       /* hopefully, na_factory_object_copy only copy valuable properties
+                       /* hopefully, fma_factory_object_copy only copy valuable properties
                         * keeping dynamic variables as parent pointer, provider and provider
                         * data, read-only status - notably children are not impacted by this


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]